/*  fgwirc - fungw based minimal irc client
    Copyright (C) 2019,2021  Tibor 'Igor2' Palinkas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

    Project page and contact: http://repo.hu/projects/fgwirc
*/

#include <libfungw/fungw.h>
#include <genht/htsp.h>
#include "window.h"
#include "irc.h"
#include "global_typedefs.h"

extern char *fungw_libdir;

struct script_s {
	fgw_obj_t *obj;
	char *fn;
	char *lang;
};

extern htsp_t scripts;

int script_load(win_t *win, const char *id, const char *fn, const char *lang);
int script_unload(win_t *win, const char *id);
void script_init(void);
void script_uninit(void);

/*** script hooks ***/
typedef enum {
	SCRIPT_PRE,
	SCRIPT_ON,
	SCRIPT_POST
} script_hook_type_t;

action_hook_res_t script_parse_high(script_hook_type_t type, irc_server_t *server, const irc_from_t *from, char *low_cmd, int argc, char **argv);

/* Remove short hook named actions from the global func table so they are
   not directly callable (call_all still reaches them through long name).
   This is required because multiple scripts want to register the same
   functions and functions with the same name already registered elsewhere
   get injected in the script. */
void script_clean_hooks(void);
